@@ -32,6 +32,7 @@ import re
 import csv
 import logging
 from xml.dom import minidom, Node
+import yaml
 from xml.parsers.expat import ExpatError
 
 from hubzero.submit.LogMessage    import getLogIDMessage as getLogMessage
@@ -46,25 +47,56 @@ class JobOutput:
                          daxPath):
       daxExecutables = []
       if os.path.exists(daxPath):
-         try:
-            daxDoc = minidom.parse(daxPath)
-         except ExpatError:
-            message = "getDaxExecutables: %s file could not be parsed" % (daxPath)
-            self.logger.log(logging.ERROR,getLogMessage(message))
-         else:
-            rootNode = daxDoc.documentElement
-            children = rootNode.getElementsByTagName("executable")
+         if   daxPath.endswith('.xml') or daxPath.endswith('.dax'):
+            try:
+               daxDoc = minidom.parse(daxPath)
+            except ExpatError:
+               message = "getDaxExecutables: %s file could not be parsed" % (daxPath)
+               self.logger.log(logging.ERROR,getLogMessage(message))
+            else:
+               rootNode = daxDoc.documentElement
+               children = rootNode.getElementsByTagName("executable")
 
-            for child in children:
-               installed = child.getAttribute('installed')
-               if not installed.lower() in ('true','t'):
-                  for grandChild in child.childNodes:
-                     if grandChild.nodeType == Node.ELEMENT_NODE:
-                        if grandChild.tagName == "pfn":
-                           url = grandChild.getAttribute("url")
-                           if url.startswith("file://"):
-                              executablePath = url[len("file://"):]
-                              daxExecutables.append(executablePath)
+               for child in children:
+                  installed = child.getAttribute('installed')
+                  if not installed.lower() in ('true','t'):
+                     for grandChild in child.childNodes:
+                        if grandChild.nodeType == Node.ELEMENT_NODE:
+                           if grandChild.tagName == "pfn":
+                              url = grandChild.getAttribute("url")
+                              if url.startswith("file://"):
+                                 executablePath = url[len("file://"):]
+                                 daxExecutables.append(executablePath)
+         elif daxPath.endswith('.yml'):
+            try:
+               with open(daxPath,'r') as fpTransactions:
+                  daxDoc = yaml.load(fpTransactions,Loader=yaml.CSafeLoader)
+            except ExpatError:
+               message = "getDaxExecutables: %s file could not be parsed" % (daxPath)
+               self.logger.log(logging.ERROR,getLogMessage(message))
+            else:
+               try:
+                  tc = daxDoc['transformationCatalog']
+               except KeyError:
+                  pass
+               else:
+                  try:
+                     transformations = tc['transformations']
+                  except KeyError:
+                     pass
+                  else:
+                     for transformation in transformations:
+                        try:
+                           sites = transformation['sites']
+                        except KeyError:
+                           pass
+                        else: 
+                           for site in sites:
+                              if site['name'] == 'local':
+                                 executablePath = site['pfn']
+                                 daxExecutables.append(executablePath)
+         else:
+            self.logger.log(logging.ERROR,getLogMessage("dax %s file has unrecognized format" % (daxPath)))
       else:
          self.logger.log(logging.ERROR,getLogMessage("dax %s file is missing" % (daxPath)))
 
@@ -162,7 +194,7 @@ class JobOutput:
       if os.path.exists(jobStateLogPath):
          condorIds = {}
          try:
-            fpJobStateLog = open(jobStateLogPath,'rb')
+            fpJobStateLog = open(jobStateLogPath,'r')
             try:
                while True:
                   record = fpJobStateLog.readline()
@@ -183,11 +215,11 @@ class JobOutput:
             jobStatsPath = os.path.join(instanceDirectory,'pegasusjobstats.csv')
             if os.path.exists(jobStatsPath):
                try:
-                  fpJobStats = open(jobStatsPath,'rb')
+                  fpJobStats = open(jobStatsPath,'r')
                   try:
                      csvReader = csv.reader(CommentedFile(fpJobStats))
                      try:
-                        headers = csvReader.next()
+                        headers = next(csvReader)
                         try:
                            columnDaxLabel    = headers.index('Dax_Label')
                            columnSite        = headers.index('Site')
@@ -373,7 +405,7 @@ class JobOutput:
          jobStateLogPath = os.path.join(pegasusFileDirectory,'jobstate.log')
       if os.path.exists(jobStateLogPath):
          try:
-            fpJobStateLog = open(jobStateLogPath,'rb')
+            fpJobStateLog = open(jobStateLogPath,'r')
             try:
                while True:
                   record = fpJobStateLog.readline()
@@ -445,7 +477,7 @@ class JobOutput:
          jobStateLogPath = os.path.join(pegasusFileDirectory,'jobstate.log')
       if os.path.exists(jobStateLogPath):
          try:
-            fpJobStateLog = open(jobStateLogPath,'rb')
+            fpJobStateLog = open(jobStateLogPath,'r')
             try:
                while True:
                   record = fpJobStateLog.readline()
@@ -543,7 +575,7 @@ class JobOutput:
       if os.path.exists(jobStateLogPath):
          condorIds = {}
          try:
-            fpJobStateLog = open(jobStateLogPath,'rb')
+            fpJobStateLog = open(jobStateLogPath,'r')
             try:
                while True:
                   record = fpJobStateLog.readline()
@@ -568,11 +600,11 @@ class JobOutput:
             jobStatsPath = os.path.join(instanceDirectory,'pegasusjobstats.csv')
             if os.path.exists(jobStatsPath):
                try:
-                  fpJobStats = open(jobStatsPath,'rb')
+                  fpJobStats = open(jobStatsPath,'r')
                   try:
                      csvReader = csv.reader(CommentedFile(fpJobStats))
                      try:
-                        headers = csvReader.next()
+                        headers = next(csvReader)
                         try:
                            columnDaxLabel    = headers.index('Dax_Label')
                            columnSite        = headers.index('Site')
